@@ -547,8 +547,15 @@ class Distributive(object):
                 mapExtName = {DirectoryDistributive: "dir",
                               IsoDistributive: "isodir",
                               FlashDistributive: "flash",
+                              ContainerDistributive: "lxc",
                               PartitionDistributive: "partdir"}
                 extname = mapExtName.get(distr.__class__, "")
+                if isinstance(distr, ContainerDistributive):
+                    d = distr.get_information()
+                    d['ext'] = extname
+                    return d.copy()
+                if isinstance(distr, ArchiveDistributive):
+                    raise DistributiveError("Not for archive distributive")
                 image = distr.convertToDirectory()
             except Exception as e:
                 # TODO: отладка почему образ не подходит
@@ -1337,6 +1344,7 @@ class ArchiveDistributive(Distributive):
     def convertToDirectory(self):
         """Get archive as directory (unpack to directory)"""
         # check may be the archive already unpacked
+        raise DistributiveError(_("Unsupported"))
         mdirectory = self.mdirectory
         for child in self.childs:
             if isinstance(child, DirectoryDistributive) and \
