@@ -103,7 +103,7 @@ class ResolutionVariable(VideoVariable):
                     example="(%s:%s)" % (_("Example"), "1024x768")))
 
 
-class VariableOsInstallX11Resolution(ResolutionVariable):
+class VariableOsInstallX11ResolutionPreferred(ResolutionVariable):
     """
     X.org resolution
     """
@@ -112,7 +112,7 @@ class VariableOsInstallX11Resolution(ResolutionVariable):
     metavalue = "<width>x<height>"
     # разрешение по умолчанию пустое - это нужно для livecd
     # для автоопределения разрешения xorg сервером
-    fallback_resolution = ""
+    preferred_resolution = ""
 
     def init(self):
         self.help = _("set the Xorg resolution")
@@ -121,13 +121,27 @@ class VariableOsInstallX11Resolution(ResolutionVariable):
     def get(self):
         # get resolution from xorg.log
         res = self.Get('os_x11_resolution')
-        if res or self.Get('install.os_install_root_type') in (
-                'livecd', 'usb-hdd'):
-            return res or self.fallback_resolution
+        if res:
+            return res
+        else:
+            return self.preferred_resolution
+
+class VariableOsInstallX11Resolution(ResolutionVariable):
+    """
+    X.org resolution
+    """
+    fallback_resolution = "1024x768"
+
+    def get(self):
+        # get resolution from xorg.log
+        for vn in ('install.os_install_x11_resolution_preferred',
+                   'install.os_install_fb_resolution'):
+            res = self.Get(vn)
+            if res:
+                return res
         else:
             return self.fallback_resolution
 
-
 class VariableOsInstallX11VideoAvailable(VideoVariable):
     """
     Get available (already installed or installable drivers
